#!/usr/bin/env python3
# Timestamp: "2026-03-16 (ywatanabe)"
# File: /home/ywatanabe/proj/scitex-notification/src/scitex_notification/_cli/__init__.py

"""CLI entry point for scitex-notification."""

from scitex_notification._cli._main import cli as main

__all__ = ["main"]

# EOF
